{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "index a sequence file for use by esl-sfetch",
            "doc": "https://github.com/EddyRivasLab/easel",
            "hints": [
                {
                    "dockerPull": "quay.io/biocontainers/hmmer:3.2.1--hf484d3e_1",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "esl-index.sh"
            ],
            "requirements": [
                {
                    "listing": [
                        "$(inputs.sequences)"
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "coresMin": 4,
                    "ramMin": 5000,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "inputBinding": {
                        "prefix": "-f",
                        "position": 1,
                        "valueFrom": "$(self.basename)"
                    },
                    "label": "Input fasta file.",
                    "id": "#esl-sfetch-index.cwl/sequences"
                }
            ],
            "id": "#esl-sfetch-index.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".ssi"
                    ],
                    "outputBinding": {
                        "glob": "folder/$(inputs.sequences.basename)"
                    },
                    "label": "The index file",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#esl-sfetch-index.cwl/sequences_with_index"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "extract by names from an indexed sequence file",
            "doc": "https://github.com/EddyRivasLab/easel",
            "hints": [
                {
                    "dockerPull": "quay.io/biocontainers/hmmer:3.2.1--hf484d3e_1",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "ramMin": 200,
                    "coresMin": 2,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "label": "sequence file indexed by esl-sfetch-index",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-Cf",
                        "position": 1
                    },
                    "secondaryFiles": [
                        ".ssi"
                    ],
                    "format": "http://edamontology.org/format_1929",
                    "id": "#esl-sfetch-manyseqs.cwl/indexed_sequences"
                },
                {
                    "doc": "GDF format: <newname> <from> <to> <source seqname>\nspace/tabdelimited\n",
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#esl-sfetch-manyseqs.cwl/names_contain_subseq_coords"
                }
            ],
            "baseCommand": [
                "esl-sfetch"
            ],
            "stdout": "$(inputs.indexed_sequences.basename)_$(inputs.names_contain_subseq_coords.basename).fasta",
            "outputs": [
                {
                    "type": "File",
                    "id": "#esl-sfetch-manyseqs.cwl/sequences",
                    "outputBinding": {
                        "glob": "$(inputs.indexed_sequences.basename)_$(inputs.names_contain_subseq_coords.basename).fasta"
                    }
                }
            ],
            "id": "#esl-sfetch-manyseqs.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "alpine:3.7",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMin": 2,
                    "ramMin": 200,
                    "class": "ResourceRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "label": "output from infernal cmsearch",
                    "format": "http://edamontology.org/format_3475",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#extract-coords_awk.cwl/infernal_matches"
                },
                {
                    "label": "output file name",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-n",
                        "valueFrom": "$(self? self : inputs.infernal_matches.basename)\n"
                    },
                    "default": "",
                    "id": "#extract-coords_awk.cwl/name"
                }
            ],
            "baseCommand": "awk_tool",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3475",
                    "outputBinding": {
                        "glob": "*matched_seqs_with_coords*"
                    },
                    "id": "#extract-coords_awk.cwl/matched_seqs_with_coords"
                }
            ],
            "doc": "The awk script takes the output of Infernal's cmsearch so-called fmt=1 mode\nand makes it suitable for use by esl-sfetch, a sequence selector\n\nReading the user's guide for Infernal, Version 1.1.2; July 2016\nhttp://eddylab.org/infernal/Userguide.pdf#page=60 we see that\nthe relevant fields in the cmsearch output are:\n(column number: explanation)\n1: The name of the target sequence or profile\n3: The name of the query sequence or profile\n8: The start of the alignment of this hit with respect to the\n    sequence, numbered 1..L for a sequence of L residues.\n9: The end of the alignment of this hit with respect to the sequence,\n    numbered 1..L for a sequence of L residues\n\nLikewise the format esl-sfetch wants is: <newname> <from> <to> <source seqname>\n\nPutting it all together we see that the newname (which esl-sfetch with\noutput using) is a concatenation of the original name, the sequence\nnumber, and the coordinates.\n",
            "id": "#extract-coords_awk.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 200,
                    "class": "ResourceRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#pull_ncrnas.cwl/hits"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#pull_ncrnas.cwl/model"
                }
            ],
            "baseCommand": [
                "pull_ncrnas.sh"
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.RF*"
                    },
                    "id": "#pull_ncrnas.cwl/matches"
                }
            ],
            "id": "#pull_ncrnas.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 16,
                    "ramMin": 200,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#move.cwl/initial_file"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#move.cwl/out_file_name"
                }
            ],
            "baseCommand": [
                "mv"
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.out_file_name)"
                    },
                    "id": "#move.cwl/renamed_file"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "alpine:3.7"
                }
            ],
            "id": "#move.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMin": 16,
                    "ramMin": 200,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#gzip.cwl/uncompressed_file"
                }
            ],
            "baseCommand": [
                "pigz"
            ],
            "arguments": [
                "-p",
                "16",
                "-c"
            ],
            "stdout": "$(inputs.uncompressed_file.basename).gz",
            "outputs": [
                {
                    "type": "File",
                    "id": "#gzip.cwl/compressed_file",
                    "outputBinding": {
                        "glob": "$(inputs.uncompressed_file.basename).gz"
                    }
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "alpine:3.7"
                }
            ],
            "id": "#gzip.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "label": "extract other ncrnas!",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/cmsearch_file"
                },
                {
                    "type": "File",
                    "id": "#main/input_sequences"
                },
                {
                    "type": "string",
                    "id": "#main/name_string"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/other_ncRNA_ribosomal_models"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/gzip_files/compressed_file",
                    "id": "#main/ncrnas"
                }
            ],
            "steps": [
                {
                    "run": "#extract-coords_awk.cwl",
                    "in": [
                        {
                            "source": "#main/cmsearch_file",
                            "id": "#main/extract_coords/infernal_matches"
                        },
                        {
                            "source": "#main/name_string",
                            "id": "#main/extract_coords/name"
                        }
                    ],
                    "out": [
                        "#main/extract_coords/matched_seqs_with_coords"
                    ],
                    "id": "#main/extract_coords"
                },
                {
                    "run": "#pull_ncrnas.cwl",
                    "in": [
                        {
                            "source": "#main/extract_coords/matched_seqs_with_coords",
                            "id": "#main/get_coords/hits"
                        },
                        {
                            "source": "#main/other_ncRNA_ribosomal_models",
                            "id": "#main/get_coords/model"
                        }
                    ],
                    "out": [
                        "#main/get_coords/matches"
                    ],
                    "id": "#main/get_coords"
                },
                {
                    "run": "#esl-sfetch-manyseqs.cwl",
                    "scatter": "#main/get_ncrnas/names_contain_subseq_coords",
                    "in": [
                        {
                            "source": "#main/index_reads/sequences_with_index",
                            "id": "#main/get_ncrnas/indexed_sequences"
                        },
                        {
                            "source": "#main/get_coords/matches",
                            "id": "#main/get_ncrnas/names_contain_subseq_coords"
                        }
                    ],
                    "out": [
                        "#main/get_ncrnas/sequences"
                    ],
                    "id": "#main/get_ncrnas"
                },
                {
                    "run": "#gzip.cwl",
                    "scatter": "#main/gzip_files/uncompressed_file",
                    "in": [
                        {
                            "source": "#main/rename_ncrnas/renamed_file",
                            "id": "#main/gzip_files/uncompressed_file"
                        }
                    ],
                    "out": [
                        "#main/gzip_files/compressed_file"
                    ],
                    "id": "#main/gzip_files"
                },
                {
                    "run": "#esl-sfetch-index.cwl",
                    "in": [
                        {
                            "source": "#main/input_sequences",
                            "id": "#main/index_reads/sequences"
                        }
                    ],
                    "out": [
                        "#main/index_reads/sequences_with_index"
                    ],
                    "id": "#main/index_reads"
                },
                {
                    "run": "#move.cwl",
                    "scatter": "#main/rename_ncrnas/initial_file",
                    "in": [
                        {
                            "source": "#main/get_ncrnas/sequences",
                            "id": "#main/rename_ncrnas/initial_file"
                        },
                        {
                            "valueFrom": "$(inputs.initial_file.nameroot.split(\"fasta_\")[1]).fasta",
                            "id": "#main/rename_ncrnas/out_file_name"
                        }
                    ],
                    "out": [
                        "#main/rename_ncrnas/renamed_file"
                    ],
                    "id": "#main/rename_ncrnas"
                }
            ],
            "id": "#main",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "http://edamontology.org/EDAM_1.20.owl",
        "http://edamontology.org/EDAM_1.16.owl",
        "https://schema.org/version/latest/schemaorg-current-http.rdf"
    ],
    "$namespaces": {
        "edam": "http://edamontology.org/",
        "s": "http://schema.org/"
    }
}
